==> kubernetes-model-core-6.2.0-sources.jar: io/fabric8/kubernetes/api/model/DownwardAPIVolumeSourceFluent.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface DownwardAPIVolumeSourceFluent<A extends DownwardAPIVolumeSourceFluent<A>> extends Fluent<A>{
  public Integer getDefaultMode();
  public A withDefaultMode(Integer defaultMode);
  public Boolean hasDefaultMode();
  public A addToItems(Integer index,DownwardAPIVolumeFile item);
  public A setToItems(Integer index,DownwardAPIVolumeFile item);
  public A addToItems(io.fabric8.kubernetes.api.model.DownwardAPIVolumeFile... items);
  public A addAllToItems(Collection<DownwardAPIVolumeFile> items);
  public A removeFromItems(io.fabric8.kubernetes.api.model.DownwardAPIVolumeFile... items);
  public A removeAllFromItems(Collection<DownwardAPIVolumeFile> items);
  public A removeMatchingFromItems(Predicate<DownwardAPIVolumeFileBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<DownwardAPIVolumeFile> getItems();
  public List<DownwardAPIVolumeFile> buildItems();
  public DownwardAPIVolumeFile buildItem(Integer index);
  public DownwardAPIVolumeFile buildFirstItem();
  public DownwardAPIVolumeFile buildLastItem();
  public DownwardAPIVolumeFile buildMatchingItem(Predicate<DownwardAPIVolumeFileBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<DownwardAPIVolumeFileBuilder> predicate);
  public A withItems(List<DownwardAPIVolumeFile> items);
  public A withItems(io.fabric8.kubernetes.api.model.DownwardAPIVolumeFile... items);
  public Boolean hasItems();
  public DownwardAPIVolumeSourceFluent.ItemsNested<A> addNewItem();
  public DownwardAPIVolumeSourceFluent.ItemsNested<A> addNewItemLike(DownwardAPIVolumeFile item);
  public DownwardAPIVolumeSourceFluent.ItemsNested<A> setNewItemLike(Integer index,DownwardAPIVolumeFile item);
  public DownwardAPIVolumeSourceFluent.ItemsNested<A> editItem(Integer index);
  public DownwardAPIVolumeSourceFluent.ItemsNested<A> editFirstItem();
  public DownwardAPIVolumeSourceFluent.ItemsNested<A> editLastItem();
  public DownwardAPIVolumeSourceFluent.ItemsNested<A> editMatchingItem(Predicate<DownwardAPIVolumeFileBuilder> predicate);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ItemsNested<N> extends Nested<N>,DownwardAPIVolumeFileFluent<DownwardAPIVolumeSourceFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}

==> kubernetes-model-core-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/DownwardAPIVolumeSourceFluent.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface DownwardAPIVolumeSourceFluent<A extends DownwardAPIVolumeSourceFluent<A>> extends Fluent<A>{
  public Integer getDefaultMode();
  public A withDefaultMode(Integer defaultMode);
  public Boolean hasDefaultMode();
  public A addToItems(int index,DownwardAPIVolumeFile item);
  public A setToItems(int index,DownwardAPIVolumeFile item);
  public A addToItems(io.fabric8.kubernetes.api.model.DownwardAPIVolumeFile... items);
  public A addAllToItems(Collection<DownwardAPIVolumeFile> items);
  public A removeFromItems(io.fabric8.kubernetes.api.model.DownwardAPIVolumeFile... items);
  public A removeAllFromItems(Collection<DownwardAPIVolumeFile> items);
  public A removeMatchingFromItems(Predicate<DownwardAPIVolumeFileBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<DownwardAPIVolumeFile> getItems();
  public List<DownwardAPIVolumeFile> buildItems();
  public DownwardAPIVolumeFile buildItem(int index);
  public DownwardAPIVolumeFile buildFirstItem();
  public DownwardAPIVolumeFile buildLastItem();
  public DownwardAPIVolumeFile buildMatchingItem(Predicate<DownwardAPIVolumeFileBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<DownwardAPIVolumeFileBuilder> predicate);
  public A withItems(List<DownwardAPIVolumeFile> items);
  public A withItems(io.fabric8.kubernetes.api.model.DownwardAPIVolumeFile... items);
  public Boolean hasItems();
  public DownwardAPIVolumeSourceFluent.ItemsNested<A> addNewItem();
  public DownwardAPIVolumeSourceFluent.ItemsNested<A> addNewItemLike(DownwardAPIVolumeFile item);
  public DownwardAPIVolumeSourceFluent.ItemsNested<A> setNewItemLike(int index,DownwardAPIVolumeFile item);
  public DownwardAPIVolumeSourceFluent.ItemsNested<A> editItem(int index);
  public DownwardAPIVolumeSourceFluent.ItemsNested<A> editFirstItem();
  public DownwardAPIVolumeSourceFluent.ItemsNested<A> editLastItem();
  public DownwardAPIVolumeSourceFluent.ItemsNested<A> editMatchingItem(Predicate<DownwardAPIVolumeFileBuilder> predicate);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ItemsNested<N> extends Nested<N>,DownwardAPIVolumeFileFluent<DownwardAPIVolumeSourceFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}
